
# This file was generated by 'versioneer.py' (0.29) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2024-06-26T16:17:56+0200",
 "dirty": true,
 "error": null,
 "full-revisionid": "a0a33189586ed4186c9b6ef3c91fc9f21a041df2",
 "version": "0.6.3"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
